@@ -2,17 +2,19 @@
 """
 Easy Code Reader MCP Server
 
-这是一个 Model Context Protocol (MCP) 服务器，用于从 Maven 依赖中读取 Java 源代码。
+这是一个 Model Context Protocol (MCP) 服务器，用于读取 Java 源代码。
 
 主要功能：
-- 从 Maven 仓库读取 JAR 包源代码
-- 支持从 sources jar 提取源码
-- 支持反编译 class 文件
-- 自动管理大型响应内容
+- 从 Maven 仓库读取 JAR 包源代码（支持 SNAPSHOT 版本）
+- 从本地项目目录读取源代码（支持多模块项目）
+- 支持从 sources jar 提取源码或反编译 class 文件
+- 智能选择反编译器（CFR/Fernflower）
 
-Example usage with MCP client:
-    The server provides the following tools:
-    - read_jar_source: 读取 Maven 依赖中的 Java 类源代码
+提供的工具：
+- read_jar_source: 读取 Maven 依赖中的 Java 类源代码
+- read_project_code: 读取本地项目中的源代码
+- list_all_project: 列举项目目录下的所有项目
+- list_project_files: 列出项目中的源代码和配置文件
 """
 
 import asyncio
@@ -24,22 +26,19 @@ from typing import Any, List, Optional
 
 from mcp.server import Server
 from mcp.server.stdio import stdio_server
-from mcp.types import Tool, TextContent
+from mcp.types import Tool, TextContent, Resource
 
 from .config import Config
 from .decompiler import JavaDecompiler
-from .response_manager import ResponseManager
 
 # 配置日志系统
 import os
 log_file = os.path.join(os.path.dirname(__file__), "easy_code_reader.log")
 logging.basicConfig(
-    level=logging.DEBUG,
-    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
+    level=logging.INFO,  # 生产环境使用 INFO 级别
+    format='%(asctime)s - %(levelname)s - %(message)s',  # 简化格式，去除模块名
     handlers=[
-        # 写入日志文件
-        logging.FileHandler(log_file),
-        # 同时输出到控制台（非 MCP 服务器模式时）
+        logging.FileHandler(log_file, encoding='utf-8'),
         logging.StreamHandler()
     ]
 )
@@ -60,7 +59,7 @@ class EasyCodeReaderServer:
             maven_repo_path: 自定义 Maven 仓库路径（可选）
             project_dir: 项目目录路径（可选）
         """
-        logger.info("正在初始化 Easy Code Reader MCP 服务器...")
+        logger.info("正在初始化 MCP 服务器...")
         
         # 创建 MCP 服务器实例
         self.server = Server(Config.SERVER_NAME)
@@ -70,36 +69,29 @@ class EasyCodeReaderServer:
             Config.set_maven_home(maven_repo_path)
         
         self.maven_home = Config.get_maven_home()
-        logger.info(f"Maven 仓库位置: {self.maven_home}")
         
         # 检查 Maven 仓库是否存在
         if not self.maven_home.exists():
-            logger.warning(f"在 {self.maven_home} 未找到 Maven 仓库")
+            logger.warning(f"Maven 仓库不存在: {self.maven_home}")
         else:
-            jar_count = len(list(self.maven_home.rglob("*.jar")))
-            logger.info(f"在仓库中找到 {jar_count} 个 JAR 文件")
+            logger.info(f"Maven 仓库: {self.maven_home}")
         
         # 设置项目目录路径
         self.project_dir = Path(project_dir) if project_dir else None
         if self.project_dir:
-            logger.info(f"项目目录位置: {self.project_dir}")
             if not self.project_dir.exists():
-                logger.warning(f"在 {self.project_dir} 未找到项目目录")
+                logger.warning(f"项目目录不存在: {self.project_dir}")
+            else:
+                logger.info(f"项目目录: {self.project_dir}")
         
         # 初始化 Java 反编译器
-        logger.info("正在初始化 Java 反编译器...")
         self.decompiler = JavaDecompiler()
-        if self.decompiler.fernflower_jar:
-            logger.info(f"Fernflower 反编译器已就绪")
-        else:
-            logger.warning("Fernflower 反编译器不可用")
-        
-        # 初始化响应管理器
-        self.response_manager = ResponseManager()
+        if not self.decompiler.fernflower_jar and not self.decompiler.cfr_jar:
+            logger.error("未找到任何可用的反编译器，反编译功能将不可用")
         
         # 设置 MCP 服务器处理程序
         self.setup_handlers()
-        logger.info("Easy Code Reader MCP 服务器初始化完成!")
+        logger.info("MCP 服务器初始化完成")
     
     def setup_handlers(self):
         """设置 MCP 服务器处理程序"""
@@ -110,7 +102,13 @@ class EasyCodeReaderServer:
             return [
                 Tool(
                     name="read_jar_source",
-                    description="从 Maven 依赖中读取 Java 类的源代码（优先从 sources jar，否则反编译）",
+                    description=(
+                        "从 Maven 依赖中读取 Java 类的源代码。"
+                        "工作流程：1) 首先尝试从 -sources.jar 中提取原始源代码；2) 如果 sources jar 不存在，自动使用反编译器（CFR 或 Fernflower）反编译 class 文件。"
+                        "支持 SNAPSHOT 版本的智能处理，会自动查找带时间戳的最新版本。"
+                        "适用场景：阅读第三方库源码（如 Spring、MyBatis）、理解依赖实现细节、排查依赖相关问题。"
+                        "注意：需要提供完整的 Maven 坐标（group_id、artifact_id、version）和完全限定的类名（如 org.springframework.core.SpringVersion）。"
+                    ),
                     inputSchema={
                         "type": "object",
                         "properties": {
@@ -141,7 +139,14 @@ class EasyCodeReaderServer:
                 ),
                 Tool(
                     name="read_project_code",
-                    description="从本地项目目录中读取指定项目的代码类源代码",
+                    description=(
+                        "从本地项目目录中读取指定文件的源代码。"
+                        "支持两种输入格式：1) 完全限定的类名（如 com.example.service.UserService）；2) 相对路径（如 src/main/java/com/example/MyClass.java 或 core/src/main/java/com/example/MyClass.java）。"
+                        "自动支持多模块 Maven/Gradle 项目，会递归搜索子模块中的文件。"
+                        "搜索策略：优先在项目根目录查找，如果未找到则自动在所有子模块（包含 pom.xml 或 build.gradle 的目录）中搜索。"
+                        "适用场景：阅读本地项目源码、分析项目结构、理解业务逻辑实现。"
+                        "推荐流程：先使用 list_all_project 确认项目存在 → 使用 list_project_files 查看文件列表 → 使用本工具读取具体文件。"
+                    ),
                     inputSchema={
                         "type": "object",
                         "properties": {
@@ -163,7 +168,13 @@ class EasyCodeReaderServer:
                 ),
                 Tool(
                     name="list_all_project",
-                    description="列举项目目录下所有的项目文件夹名称",
+                    description=(
+                        "列举项目目录下所有的项目文件夹名称。"
+                        "返回项目目录中所有子目录的名称列表（自动过滤隐藏目录如 .git）。"
+                        "适用场景：1) 探索未知的项目目录，了解有哪些项目可用；2) 验证项目名称是否正确，避免拼写错误；3) 当用户提供不完整的项目名时，帮助推断完整名称。"
+                        "推荐使用：这是探索本地项目的第一步，先用此工具获取所有项目列表，再使用 list_project_files 查看具体项目的文件结构。"
+                        "返回格式：包含项目目录路径、项目总数和项目名称列表的 JSON 对象。"
+                    ),
                     inputSchema={
                         "type": "object",
                         "properties": {
@@ -207,7 +218,6 @@ class EasyCodeReaderServer:
         @self.server.call_tool()
         async def handle_call_tool(name: str, arguments: Any) -> List[TextContent]:
             """处理工具调用"""
-            logger.info(f"Tool called: {name} with arguments: {arguments}")
             try:
                 if name == "read_jar_source":
                     return await self._read_jar_source(**arguments)
@@ -218,10 +228,88 @@ class EasyCodeReaderServer:
                 elif name == "list_project_files":
                     return await self._list_project_files(**arguments)
                 else:
+                    logger.error(f"未知工具: {name}")
                     raise ValueError(f"Unknown tool: {name}")
             except Exception as e:
-                logger.error(f"Error handling tool {name}: {e}", exc_info=True)
+                logger.error(f"工具 {name} 执行失败: {str(e)}", exc_info=True)
                 return [TextContent(type="text", text=f"Error: {str(e)}")]
+        
+        @self.server.list_resources()
+        async def handle_list_resources() -> List[Resource]:
+            """列出可用的资源"""
+            return [
+                Resource(
+                    uri="easy-code-reader://guide",
+                    name="Easy Code Reader 使用指南",
+                    description=(
+                        "Github仓库: [Github - easy-code-reader](https://github.com/FangYuan33/easy-code-reader)"
+                    ),
+                    mimeType="text/markdown"
+                )
+            ]
+        
+        @self.server.read_resource()
+        async def handle_read_resource(uri: str) -> str:
+            """读取资源内容"""
+            if uri == "easy-code-reader://guide":
+                return self._get_guide_content()
+            else:
+                raise ValueError(f"Unknown resource URI: {uri}")
+    
+    def _get_guide_content(self) -> str:
+        """获取使用指南内容"""
+        maven_repo = self.maven_home if self.maven_home else "~/.m2/repository"
+        project_dir = self.project_dir if self.project_dir else "未配置"
+        
+        # 使用普通字符串拼接，避免 f-string 中嵌套 JSON 导致的语法错误
+        guide_text = "# Easy Code Reader 使用指南\n\n"
+        guide_text += "## 功能介绍\n\n"
+        guide_text += "Easy Code Reader 是一个强大的 MCP (Model Context Protocol) 服务器，专为智能读取 Java 源代码而设计，能从本地 Maven 仓库和项目目录中提取源码。\n\n"
+        guide_text += "## 配置参数说明\n\n"
+        guide_text += "- MCP 配置示例（uvx 使用示例）：\n\n"
+        guide_text += "```json\n"
+        guide_text += "{\n"
+        guide_text += '  "mcpServers": {\n'
+        guide_text += '    "easy-code-reader": {\n'
+        guide_text += '      "command": "uvx",\n'
+        guide_text += '      "args": [\n'
+        guide_text += '        "easy-code-reader",\n'
+        guide_text += '        "--maven-repo",\n'
+        guide_text += '        "/path/to/maven/repository",\n'
+        guide_text += '        "--project-dir",\n'
+        guide_text += '        "/path/to/project"\n'
+        guide_text += '      ]\n'
+        guide_text += '    }\n'
+        guide_text += '  }\n'
+        guide_text += '}\n'
+        guide_text += "```\n\n"
+        guide_text += "### 1. maven_repo（Maven 仓库路径）\n\n"
+        guide_text += f"- **当前配置：** `{maven_repo}`\n"
+        guide_text += "- **用途：** 指定本地 Maven 仓库的位置，用于查找和读取 JAR 包。\n\n"
+        guide_text += "**配置优先级：**\n"
+        guide_text += "1. 启动参数 `--maven-repo`（最高优先级）\n"
+        guide_text += "2. 环境变量 `MAVEN_HOME`（使用 $MAVEN_HOME/repository）\n"
+        guide_text += "3. 环境变量 `M2_HOME`（使用 $M2_HOME/repository）\n"
+        guide_text += "4. 环境变量 `MAVEN_REPO`\n"
+        guide_text += "5. 默认路径 `~/.m2/repository`（最低优先级）\n\n"
+        guide_text += "### 2. project_dir（项目目录路径）\n\n"
+        guide_text += f"- **当前配置：** `{project_dir}`\n"
+        guide_text += "- **用途：** 指定本地项目代码的根目录，用于读取本地项目源码。\n\n"
+        guide_text += "## 提供的工具\n\n"
+        guide_text += "1. **read_jar_source** - 读取 Maven 依赖中的 Java 类源代码\n"
+        guide_text += "2. **read_project_code** - 读取本地项目中的源代码\n"
+        guide_text += "3. **list_all_project** - 列举项目目录下的所有项目\n"
+        guide_text += "4. **list_project_files** - 列出项目中的源代码和配置文件\n\n"
+        guide_text += "## 项目仓库\n\n"
+        guide_text += "- [GitHub 仓库](https://github.com/FangYuan33/easy-code-reader)\n\n"
+        guide_text += "## 技术细节\n\n"
+        guide_text += f"- **反编译缓存位置：** `{maven_repo}/.../easy-code-reader/`\n"
+        guide_text += "- **日志文件位置：** `src/easy_code_reader/easy_code_reader.log`\n"
+        guide_text += "- **支持的文件类型：** .java, .xml, .properties, .yaml, .json, .gradle 等\n\n"
+        guide_text += "---\n\n"
+        guide_text += "💡 **提示：** 使用 AI 助手时，可以直接描述你想读取的代码，AI 会自动选择合适的工具来获取源码。\n"
+        
+        return guide_text
     
     async def _read_jar_source(self, group_id: str, artifact_id: str, version: str,
                               class_name: str, prefer_sources: bool = True) -> List[TextContent]:
@@ -262,11 +350,13 @@ class EasyCodeReaderServer:
         # 回退到反编译
         jar_path = self._get_jar_path(group_id, artifact_id, version)
         if not jar_path or not jar_path.exists():
-            return [TextContent(
-                type="text", 
-                text=f"未找到 JAR 文件: {group_id}:{artifact_id}:{version}\n" +
-                     f"请确认 Maven 仓库路径正确: {self.maven_home}"
-            )]
+            error_msg = (
+                f"未找到 JAR 文件: {group_id}:{artifact_id}:{version}\n"
+                f"Maven 仓库路径: {self.maven_home}\n"
+                f"请确认依赖已安装到本地仓库"
+            )
+            logger.warning(error_msg)
+            return [TextContent(type="text", text=error_msg)]
         
         try:
             # 对于 SNAPSHOT 版本，实际反编译使用 -SNAPSHOT.jar，但缓存使用带时间戳的版本名
@@ -275,12 +365,14 @@ class EasyCodeReaderServer:
                 snapshot_jar = self._get_snapshot_jar_path(group_id, artifact_id, version)
                 if snapshot_jar and snapshot_jar.exists():
                     actual_jar_to_decompile = snapshot_jar
-                    logger.info(f"SNAPSHOT 版本: 使用 {snapshot_jar.name} 进行反编译，缓存名为 {jar_path.name}")
             
             decompiled_code = self.decompiler.decompile_class(
                 actual_jar_to_decompile, class_name, cache_jar_name=jar_path.name if actual_jar_to_decompile != jar_path else None
             )
             
+            if not decompiled_code:
+                logger.error(f"反编译失败: {class_name} from {group_id}:{artifact_id}:{version}")
+            
             result = {
                 "class_name": class_name,
                 "artifact": f"{group_id}:{artifact_id}:{version}",
@@ -290,7 +382,7 @@ class EasyCodeReaderServer:
             return [TextContent(type="text", text=json.dumps(result, indent=2, ensure_ascii=False))]
             
         except Exception as e:
-            logger.error(f"Error extracting source code: {e}", exc_info=True)
+            logger.error(f"提取源代码时出错: {str(e)}", exc_info=True)
             return [TextContent(type="text", text=f"提取源代码时出错: {str(e)}")]
     
     async def _read_project_code(self, project_name: str, class_name: str, 
@@ -323,26 +415,30 @@ class EasyCodeReaderServer:
         if not target_dir.exists():
             return [TextContent(type="text", text=f"错误: 项目目录不存在: {target_dir}")]
         
-        # 检查项目是否存在
-        project_path = target_dir / project_name
-        if not project_path.exists() or not project_path.is_dir():
-            return [TextContent(
-                type="text", 
-                text=f"错误: {project_name} 项目不存在，请执行 list_all_project tool 检查项目是否存在"
-            )]
-        
         # 尝试查找文件
         # 1. 如果 class_name 看起来像是路径（包含 / 或常见文件扩展名），直接使用
         if '/' in class_name or class_name.endswith('.java'):
-            # 先在项目根目录查找
-            file_path = project_path / class_name
-            if file_path.exists() and file_path.is_file():
-                return await self._return_file_content(project_name, class_name, file_path)
+            # 优先尝试：直接在 target_dir 下查找（适用于 class_name 包含完整相对路径的情况）
+            file_path_direct = target_dir / class_name
+            if file_path_direct.exists() and file_path_direct.is_file():
+                logger.info(f"直接在 project_dir 下找到文件: {file_path_direct}")
+                return await self._return_file_content(project_name, class_name, file_path_direct)
             
-            # 在子模块中查找
-            result = self._search_in_modules(project_path, class_name)
-            if result:
-                return await self._return_file_content(project_name, class_name, result)
+            # 检查项目子目录是否存在
+            project_path = target_dir / project_name
+            if project_path.exists() and project_path.is_dir():
+                # 在项目子目录中查找
+                file_path = project_path / class_name
+                if file_path.exists() and file_path.is_file():
+                    return await self._return_file_content(project_name, class_name, file_path)
+                
+                # 在子模块中查找
+                result = self._search_in_modules(project_path, class_name)
+                if result:
+                    return await self._return_file_content(project_name, class_name, result)
+            else:
+                # 项目子目录不存在，但 class_name 是路径形式，已经在 target_dir 直接查找过了
+                logger.warning(f"在 {target_dir} 下未找到文件: {class_name}")
         
         # 2. 将类名转换为路径，搜索可能的源文件
         # 支持 Java 类名格式: com.example.MyClass -> com/example/MyClass.java
@@ -355,22 +451,35 @@ class EasyCodeReaderServer:
             f"{class_path}.java",
         ]
         
-        # 尝试各种路径模式 - 先在项目根目录
-        for pattern in search_patterns:
-            file_path = project_path / pattern
-            if file_path.exists() and file_path.is_file():
-                return await self._return_file_content(project_name, class_name, file_path)
-        
-        # 在子模块中搜索
-        for pattern in search_patterns:
-            result = self._search_in_modules(project_path, pattern)
-            if result:
-                return await self._return_file_content(project_name, class_name, result)
+        # 检查项目子目录是否存在
+        project_path = target_dir / project_name
+        if project_path.exists() and project_path.is_dir():
+            # 尝试各种路径模式 - 在项目子目录中
+            for pattern in search_patterns:
+                file_path = project_path / pattern
+                if file_path.exists() and file_path.is_file():
+                    return await self._return_file_content(project_name, class_name, file_path)
+            
+            # 在子模块中搜索
+            for pattern in search_patterns:
+                result = self._search_in_modules(project_path, pattern)
+                if result:
+                    return await self._return_file_content(project_name, class_name, result)
+        else:
+            # 项目子目录不存在，尝试直接在 target_dir 下搜索
+            logger.info(f"项目子目录 {project_path} 不存在，尝试在 {target_dir} 下搜索")
+            for pattern in search_patterns:
+                file_path_direct = target_dir / pattern
+                if file_path_direct.exists() and file_path_direct.is_file():
+                    logger.info(f"在 project_dir 下找到文件: {file_path_direct}")
+                    return await self._return_file_content(project_name, class_name, file_path_direct)
         
         # 如果找不到文件，返回错误信息
+        logger.warning(f"在项目 {project_name} 中未找到类: {class_name}")
         return [TextContent(
             type="text",
-            text=f"错误: 在项目 {project_name} 中未找到类 {class_name}，尝试的路径包括: {', '.join(search_patterns)}"
+            text=f"错误: 在项目 {project_name} 中未找到类 {class_name}\n"
+                 f"建议: 先使用 list_project_files 查看项目文件列表"
         )]
     
     def _search_in_modules(self, project_path: Path, relative_path: str) -> Optional[Path]:
@@ -398,10 +507,9 @@ class EasyCodeReaderServer:
                 # 在模块中查找文件
                 file_path = subdir / relative_path
                 if file_path.exists() and file_path.is_file():
-                    logger.info(f"在子模块 {subdir.name} 中找到文件: {file_path}")
                     return file_path
         except Exception as e:
-            logger.warning(f"搜索子模块时出错: {e}")
+            logger.error(f"搜索子模块时出错: {e}", exc_info=True)
         
         return None
     
@@ -428,7 +536,7 @@ class EasyCodeReaderServer:
             }
             return [TextContent(type="text", text=json.dumps(result, indent=2, ensure_ascii=False))]
         except Exception as e:
-            logger.error(f"Error reading file: {e}", exc_info=True)
+            logger.error(f"读取文件失败 {file_path}: {str(e)}", exc_info=True)
             return [TextContent(type="text", text=f"读取文件时出错: {str(e)}")]
     
     async def _list_all_project(self, project_dir: Optional[str] = None) -> List[TextContent]:
@@ -464,7 +572,7 @@ class EasyCodeReaderServer:
             
             return [TextContent(type="text", text=json.dumps(result, indent=2, ensure_ascii=False))]
         except Exception as e:
-            logger.error(f"Error listing projects: {e}", exc_info=True)
+            logger.error(f"列举项目失败: {str(e)}", exc_info=True)
             return [TextContent(type="text", text=f"列举项目时出错: {str(e)}")]
 
     async def _list_project_files(self, project_name: str, sub_path: Optional[str] = None, 
@@ -604,8 +712,10 @@ class EasyCodeReaderServer:
                         if should_include_file(item.name):
                             file_relative = f"{relative_path}/{item.name}" if relative_path else item.name
                             file_paths.append(file_relative)
+            except PermissionError as e:
+                logger.warning(f"无权限访问目录 {path}: {e}")
             except Exception as e:
-                logger.warning(f"遍历目录 {path} 时出错: {e}")
+                logger.error(f"遍历目录 {path} 时出错: {e}")
 
         collect_files(start_path, search_prefix)
 
@@ -640,7 +750,6 @@ class EasyCodeReaderServer:
                 if timestamped_jars:
                     # 按文件名排序，获取最新的（时间戳最大的）
                     timestamped_jars.sort(reverse=True)
-                    logger.info(f"找到 SNAPSHOT 带时间戳的 jar: {timestamped_jars[0]}")
                     return timestamped_jars[0]
         
         # 查找主 jar 文件
@@ -687,12 +796,12 @@ class EasyCodeReaderServer:
                 if java_file in jar.namelist():
                     return jar.read(java_file).decode('utf-8', errors='ignore')
         except Exception as e:
-            logger.warning(f"从 sources jar 提取失败: {e}")
+            logger.error(f"从 sources jar 提取失败 {sources_jar}: {e}")
         return None
     
     async def run(self):
         """运行 MCP 服务器"""
-        logger.info("Starting Easy Code Reader MCP Server...")
+        logger.info("启动 MCP 服务器...")
         async with stdio_server() as (read_stream, write_stream):
             await self.server.run(
                 read_stream,
